Documentation
¶
Index ¶
- Variables
- func GetThemesDir() string
- func LoadAllCustomThemes() map[string]*Theme
- type CustomThemeFile
- type Theme
- func Catppuccin() *Theme
- func Dracula() *Theme
- func FlexokiDark() *Theme
- func FlexokiLight() *Theme
- func GithubLight() *Theme
- func GruvboxDark() *Theme
- func GruvboxLight() *Theme
- func LoadCustomTheme(path string) (*Theme, error)
- func Monokai() *Theme
- func Nord() *Theme
- func OneDark() *Theme
- func SolarizedDark() *Theme
- func SolarizedLight() *Theme
- func Tokyo() *Theme
Constants ¶
This section is empty.
Variables ¶
var EverforestDark = Theme{ Name: "Everforest Dark", IsDark: true, PrimaryForeground: lipgloss.Color("#D3C6AA"), PrimaryBackground: lipgloss.Color("#2D353B"), SuccessForeground: lipgloss.Color("#A7C080"), SuccessBackground: lipgloss.Color("#2D353B"), ErrorForeground: lipgloss.Color("#E67E80"), ErrorBackground: lipgloss.Color("#2D353B"), WarningForeground: lipgloss.Color("#DBBC7F"), WarningBackground: lipgloss.Color("#2D353B"), MutedForeground: lipgloss.Color("#859289"), }
Functions ¶
func GetThemesDir ¶
func GetThemesDir() string
GetThemesDir returns the path to the custom themes directory.
func LoadAllCustomThemes ¶
LoadAllCustomThemes scans the themes directory and loads all valid theme files. Returns a map of theme key (filename without extension) to Theme.
Types ¶
type CustomThemeFile ¶
type CustomThemeFile struct {
Name string `json:"name" toml:"name"`
IsDark bool `json:"is_dark" toml:"is_dark"`
PrimaryForeground string `json:"primary_foreground" toml:"primary_foreground"`
PrimaryBackground string `json:"primary_background" toml:"primary_background"`
SuccessForeground string `json:"success_foreground" toml:"success_foreground"`
SuccessBackground string `json:"success_background" toml:"success_background"`
ErrorForeground string `json:"error_foreground" toml:"error_foreground"`
ErrorBackground string `json:"error_background" toml:"error_background"`
WarningForeground string `json:"warning_foreground" toml:"warning_foreground"`
WarningBackground string `json:"warning_background" toml:"warning_background"`
MutedForeground string `json:"muted_foreground" toml:"muted_foreground"`
}
CustomThemeFile represents the structure of a custom theme file (JSON or TOML).
type Theme ¶
type Theme struct {
Name string
IsDark bool
PrimaryForeground lipgloss.Color
PrimaryBackground lipgloss.Color
SuccessForeground lipgloss.Color
SuccessBackground lipgloss.Color
ErrorForeground lipgloss.Color
ErrorBackground lipgloss.Color
WarningForeground lipgloss.Color
WarningBackground lipgloss.Color
MutedForeground lipgloss.Color
}
func Catppuccin ¶
func Catppuccin() *Theme
func FlexokiDark ¶
func FlexokiDark() *Theme
func FlexokiLight ¶
func FlexokiLight() *Theme
func GithubLight ¶
func GithubLight() *Theme
func GruvboxDark ¶
func GruvboxDark() *Theme
func GruvboxLight ¶
func GruvboxLight() *Theme
func LoadCustomTheme ¶
LoadCustomTheme loads a theme from a JSON or TOML file.
func SolarizedDark ¶
func SolarizedDark() *Theme
func SolarizedLight ¶
func SolarizedLight() *Theme
Click to show internal directories.
Click to hide internal directories.